@@ -382,6 +382,25 @@ void scan_error (LINE_T * u, char *v, char *txt)
   longjmp (RENDEZ_VOUS (&A68_JOB), 1);
 }
 
+void scan_error_info (LINE_T * u, char *v, char *txt, char *info)
+{
+  if (info != NO_TEXT) {
+    size_t len = strlen (txt) + 3;
+    char *txti = a68_alloc(len, __FILE__, __LINE__);
+    ABEND (txti == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
+    a68_bufcpy (txti, txt, len);
+    a68_bufcat (txti, " Z", len);
+    if (errno != 0) {
+      diagnostic (A68_SUPPRESS_SEVERITY, NO_NODE, txti, u, v, info, error_specification ());
+    } else {
+      diagnostic (A68_SUPPRESS_SEVERITY, NO_NODE, txti, u, v, info, ERROR_UNSPECIFIED);
+    }
+    longjmp (RENDEZ_VOUS (&A68_JOB), 1);
+  } else {
+    scan_error(u, v, txt);
+  }
+}
+
 //! @brief Give an intelligible warning.
 
 void scan_warning (LINE_T * u, char *v, char *txt)
@@ -761,11 +780,15 @@ void diagnostic (STATUS_MASK_T sev, NODE_T * p, char *loc_str, ...)
             a68_bufcat (b, new_string (z, NO_TEXT), BUFFER_SIZE);
           } else if (t[0] == 'Y') {
             char *loc_string = va_arg (args, char *);
-            a68_bufcat (b, loc_string, BUFFER_SIZE);
+            if (loc_string != NO_TEXT) {
+              a68_bufcat (b, loc_string, BUFFER_SIZE);
+            }
           } else if (t[0] == 'Z') {
             char *loc_string = va_arg (args, char *);
             a68_bufcat (b, "\"", BUFFER_SIZE);
-            a68_bufcat (b, loc_string, BUFFER_SIZE);
+            if (loc_string != NO_TEXT) {
+              a68_bufcat (b, loc_string, BUFFER_SIZE);
+            }
             a68_bufcat (b, "\"", BUFFER_SIZE);
           } else {
             char q[2];
