@@ -110,25 +110,53 @@ static char *win32_realpath (char *name, char *resolved)
 char *a68_relpath (char *p1, char *p2, char *fn)
 {
   char q[PATH_MAX + 1];
-  a68_bufcpy (q, p1, PATH_MAX);
-  a68_bufcat (q, "/", PATH_MAX);
-  a68_bufcat (q, p2, PATH_MAX);
+  ASSERT (p1 != NO_TEXT);
+  ASSERT (p2 != NO_TEXT);
+  ASSERT (fn != NO_TEXT);
+#if defined (BUILD_WIN32)
+  if (p2[0] == '\\') {
+    a68_bufcpy (q, p2, PATH_MAX);
+  } else {
+    a68_bufcpy (q, p1, PATH_MAX);
+    a68_bufcat (q, "\\", PATH_MAX);
+    a68_bufcat (q, p2, PATH_MAX);
+  }
+  a68_bufcat (q, "\\", PATH_MAX);
+  a68_bufcat (q, fn, PATH_MAX);
+#else
+  if (p2[0] == '/') {
+// Absolute path starting at root.
+    a68_bufcpy (q, p2, PATH_MAX);
+  } else if (p2[0] == '~') {
+// "~" is a shell extension, not Unix.
+// We handle it anyway, as a courtesy.
+    a68_bufcpy (q, getenv("HOME"), PATH_MAX);
+    a68_bufcat (q, &p2[1], PATH_MAX);
+  } else {
+    a68_bufcpy (q, p1, PATH_MAX);
+    a68_bufcat (q, "/", PATH_MAX);
+    a68_bufcat (q, p2, PATH_MAX);
+  }
   a68_bufcat (q, "/", PATH_MAX);
   a68_bufcat (q, fn, PATH_MAX);
-// Home directory shortcut ~ is a shell extension.
-  if (strchr (q, '~') != NO_TEXT) {
-    return NO_TEXT;
-  }
-  char *r = (char *) get_fixed_heap_space (PATH_MAX + 1);
-  ABEND (r == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
+#endif
 // Error handling in the caller!
   errno = 0;
 #if defined (BUILD_WIN32)
-  r = win32_realpath (q, NO_TEXT);
+  char *r = win32_realpath (q, NO_TEXT);
 #else
-  r = realpath (q, NO_TEXT);
+  char *r = realpath (q, NO_TEXT);
 #endif
-  return r;
+  if (r != NO_TEXT) {
+    size_t len = strlen (r) + 1;
+    char *rc = (char *) get_fixed_heap_space (len);
+    ABEND (rc == NO_TEXT, ERROR_OUT_OF_CORE, __func__);
+    a68_bufcpy (rc, r, len);
+    free (r);
+    return rc;
+  } else {
+    return NO_TEXT;
+  }
 }
 
 //! @brief PROC (STRING) STRING realpath
