@@ -484,7 +484,7 @@ void include_files (LINE_T * top)
         if (fn != NO_TEXT) {
           a68_bufcpy (fnb, fn, BUFFER_SIZE);
         } else {
-          SCAN_ERROR (A68_TRUE, NO_LINE, NO_TEXT, ERROR_SOURCE_FILE_INCLUDE_OPEN);
+          SCAN_ERROR_INFO (A68_TRUE, NO_LINE, NO_TEXT, ERROR_SOURCE_FILE_INCLUDE_OPEN, fnb);
         }
         fnwid = (int) strlen (fnb) + 1;
         fn = (char *) get_fixed_heap_space ((size_t) fnwid);
@@ -498,7 +498,7 @@ void include_files (LINE_T * top)
 // Access the file.
         errno = 0;
         fd = open (fn, O_RDONLY | O_BINARY);
-        SCAN_ERROR (fd == -1, start_l, start_c, ERROR_SOURCE_FILE_INCLUDE_OPEN);
+        SCAN_ERROR_INFO (fd == -1, start_l, start_c, ERROR_SOURCE_FILE_INCLUDE_OPEN, fnb);
         errno = 0;
         fsize = (int) lseek (fd, 0, SEEK_END);
         ASSERT (fsize >= 0);
