@@ -4,7 +4,7 @@
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
-//! Copyright 2001-2024 J. Marcel van der Veer [algol68g@xs4all.nl].
+//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
 
 //! @section License
 //!
@@ -1288,7 +1288,9 @@ void print_item (NODE_T * p, FILE_T f, BYTE_T * item, MOID_T * mode)
 
 void indent_crlf (FILE_T f)
 {
-  io_close_tty_line ();
+  if (f == A68_STDOUT) {
+    io_close_tty_line ();
+  }
   for (int k = 0; k < A68_MON (tabs); k++) {
     WRITE (f, "  ");
   }
