@@ -1,23 +1,27 @@
 //! @file a68g-defines.h
 //! @author J. Marcel van der Veer
-//
+
 //! @section Copyright
-//
-// This file is part of Algol68G - an Algol 68 compiler-interpreter.
-// Copyright 2001-2023 J. Marcel van der Veer <algol68g@xs4all.nl>.
-//
+//!
+//! This file is part of Algol68G - an Algol 68 compiler-interpreter.
+//! Copyright 2001-2025 J. Marcel van der Veer [algol68g@xs4all.nl].
+
 //! @section License
-//
-// This program is free software; you can redistribute it and/or modify it 
-// under the terms of the GNU General Public License as published by the 
-// Free Software Foundation; either version 3 of the License, or 
-// (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful, but 
-// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
-// or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
-// more details. You should have received a copy of the GNU General Public 
-// License along with this program. If not, see <http://www.gnu.org/licenses/>.
+//!
+//! This program is free software; you can redistribute it and/or modify it 
+//! under the terms of the GNU General Public License as published by the 
+//! Free Software Foundation; either version 3 of the License, or 
+//! (at your option) any later version.
+//!
+//! This program is distributed in the hope that it will be useful, but 
+//! WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
+//! or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for 
+//! more details. You should have received a copy of the GNU General Public 
+//! License along with this program. If not, see [http://www.gnu.org/licenses/].
+
+//! @section Synopsis
+//!
+//! General macro definitions.
 
 #if !defined (__A68G_DEFINES_H__)
 #define __A68G_DEFINES_H__
@@ -50,7 +54,7 @@
 
 // File extensions
 #define BINARY_EXTENSION ".o"
-#define LIBRARY_EXTENSION ".so"
+#define PLUGIN_EXTENSION ".so"
 #define LISTING_EXTENSION ".l"
 #define OBJECT_EXTENSION ".c"
 #define PRETTY_EXTENSION ".f"
@@ -62,7 +66,6 @@
 // which may give an undefined reference to `__stack_chk_fail_local'.
 // 
 // -Wno-parentheses-equality is needed for OpenBSD.  
-//
 
 #define A68_GCC_OPTIONS "-DA68_OPTIMISE -ggdb -fno-stack-protector -Wno-parentheses-equality"
 
@@ -76,7 +79,7 @@
 
 #define A68_DIR ".a68g"
 #define A68_HISTORY_FILE ".a68g.edit.hist"
-#define A68_NO_FILENO ((FILE_T) -1)
+#define A68_NO_FILE ((FILE_T) -1)
 #define A68_PROTECTION (S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)  // -rw-r--r--
 #define A68_READ_ACCESS (O_RDONLY)
 #define A68_WRITE_ACCESS (O_WRONLY | O_CREAT | O_TRUNC)
@@ -86,6 +89,7 @@
 #define EMBEDDED_FORMAT A68_TRUE
 #define EVEN(k) ((k) % 2 == 0)
 #define HIDDEN_TEMP_FILE_NAME ".a68g.tmp"
+#define INTERRUPT_INTERVAL 5
 #define ITEM_NOT_USED (-1)
 #define MAX_ERRORS 5
 #define MAX_PRIORITY 9
@@ -111,6 +115,10 @@
 
 #define _SKIP_ { (void) 0;}
 
+#define BUFCLR(z) {a68_bufset ((z), 0, BUFFER_SIZE + 1);}
+
+#define ABS(n) ((n) >= 0 ? (n) : -(n))
+
 #define MAX(u, v) (((u) > (v) ? (u) : (v)))
 #define MAXIMISE(u, v) ((u) = MAX (u, v))
 
@@ -207,25 +215,12 @@
 #define IN_PRELUDE(p) (LINE_NUMBER (p) <= 0)
 #define EOL(c) ((c) == NEWLINE_CHAR || (c) == NULL_CHAR)
 
-#define SIZE_ALIGNED(p) ((int) A68_ALIGN (sizeof (p)))
-#define A68_REF_SIZE (SIZE_ALIGNED (A68_REF))
-#define A68_UNION_SIZE (SIZE_ALIGNED (A68_UNION))
-
-#define A68_SOUND_BYTES(s) ((int) (BITS_PER_SAMPLE (s)) / 8 + (int) (BITS_PER_SAMPLE (s) % 8 == 0 ? 0 : 1))
-#define A68_SOUND_DATA_SIZE(s) ((int) (NUM_SAMPLES (s)) * (int) (NUM_CHANNELS (s)) * (int) (A68_SOUND_BYTES (s)))
-#define ABS(n) ((n) >= 0 ? (n) : -(n))
 #define BACKWARD(p) (p = PREVIOUS (p))
-#define BITS_WIDTH ((int) (1 + ceil (log ((REAL_T) A68_MAX_INT) / log ((REAL_T) 2))))
 #define DEFLEX(p) (DEFLEXED (p) != NO_MOID ? DEFLEXED(p) : (p))
 #define FORWARD(p) ((p) = NEXT (p))
-#define INT_WIDTH ((int) (1 + floor (log ((REAL_T) A68_MAX_INT) / log ((REAL_T) 10))))
-#define LONG_INT_WIDTH (1 + LONG_WIDTH)
 #define PM(m) (moid_to_string (m, 132, NO_NODE))
 #define SIGN(n) ((n) == 0 ? 0 : ((n) > 0 ? 1 : -1))
-#define STATUS_CLEAR(p, q) {STATUS (p) &= (~(q));}
-#define STATUS_SET(p, q) {STATUS (p) |= (q);}
-#define STATUS_TEST(p, q) ((STATUS (p) & (q)) != (unt) 0)
-#define WIS(p) where_in_source (STDOUT_FILENO, (p))
+#define WIS(p) where_in_source (A68_STDOUT, (p))
 #define WRITE(f, s) io_write_string ((f), (s));
 #define WRITELN(f, s) {WRITE ((f), "\n"); WRITE ((f), (s));}
 
@@ -282,7 +277,7 @@
 #define DEVICE_OPENED(p) ((p)->device_opened)
 #define DIAGNOSTICS(p) ((p)->diagnostics)
 #define DIGITS(p) ((p)->digits)
-#define DIGITSC(p) ((p)->digitsc)
+#define DIGITS_COMPL(p) ((p)->digits_compl)
 #define DIM(p) ((p)->dim)
 #define DISPLAY(p) ((p)->display)
 #define DRAW(p) ((p)->draw)
@@ -317,9 +312,9 @@
 #define FILE_ENTRY(p) ((p)->file_entry)
 #define FILE_GENERIC_NAME(p) (FILES (p).generic_name)
 #define FILE_INITIAL_NAME(p) (FILES (p).initial_name)
-#define FILE_LIBRARY_NAME(p) (FILES (p).library.name)
-#define FILE_LIBRARY_OPENED(p) (FILES (p).library.opened)
-#define FILE_LIBRARY_WRITEMOOD(p) (FILES (p).library.writemood)
+#define FILE_PLUGIN_NAME(p) (FILES (p).plugin.name)
+#define FILE_PLUGIN_OPENED(p) (FILES (p).plugin.opened)
+#define FILE_PLUGIN_WRITEMOOD(p) (FILES (p).plugin.writemood)
 #define FILE_LISTING_FD(p) (FILES (p).listing.fd)
 #define FILE_LISTING_NAME(p) (FILES (p).listing.name)
 #define FILE_LISTING_OPENED(p) (FILES (p).listing.opened)
@@ -360,7 +355,8 @@
 #define HAS_ROWS(p) ((p)->has_rows)
 #define HEAP(p) ((p)->heap)
 #define HEAP_POINTER(p) ((p)->heap_pointer)
-#define H_ADDR(p) ((p)->h_addr)
+// #define H_ADDR(p) ((p)->h_addr) only available with __USE_MISC allowing ancient features (4.3BSD and SysV). 
+#define H_ADDR(p) ((p)->h_addr_list[0]) 
 #define H_LENGTH(p) ((p)->h_length)
 #define ID(p) ((p)->id)
 #define IDENTIFICATION(p) ((p)->identification)
@@ -545,6 +541,7 @@
 #define SCALE_ROW(p) ((p)->scale_row)
 #define SCAN(p) ((p)->scan)
 #define SCAN_ERROR(c, u, v, txt) if (c) {scan_error (u, v, txt);}
+#define SCAN_ERROR_INFO(c, u, v, txt, info) if (c) {scan_error_info (u, v, txt, info);}
 #define SCAN_WARNING(c, u, v, txt) if (c) {scan_warning (u, v, txt);}
 #define SCOPE(p) ((p)->scope)
 #define SCOPE_ASSIGNED(p) ((p)->scope_assigned)
@@ -560,7 +557,7 @@
 #define SIZE(p) ((p)->size)
 #define SIZE1(p) ((p)->size1)
 #define SIZE2(p) ((p)->size2)
-#define SIZEC(p) ((p)->sizec)
+#define SIZE_COMPL(p) ((p)->size_compl)
 #define SLICE(p) ((p)->slice)
 #define SLICE_OFFSET(p) ((p)->slice_offset)
 #define SO(p) ((p)->so)
@@ -640,7 +637,7 @@
 #define VALUE_ERROR_MENDED(p) ((p)->value_error_mended)
 #define WARNING_COUNT(p) ((p)->warning_count)
 #define WHERE(p) ((p)->where)
-#define IF_ROW(m) (IS_FLEX (m) || IS_ROW (m) || m == M_STRING)
+#define IS_FLEXETY_ROW(m) (IS_FLEX (m) || IS_ROW (m) || m == M_STRING)
 #define IS_COERCION(p) ((p)->is_coercion)
 #define IS_FLEX(m) IS ((m), FLEX_SYMBOL)
 #define IS_LITERALLY(p, s) (strcmp (NSYMBOL (p), s) == 0)
